document.addEventListener("DOMContentLoaded", function () {
    function createElement(tag, attributes = {}, text) {
        const element = document.createElement(tag);
        Object.entries(attributes).forEach(([name, value]) => {
            // ブール値の属性は単に存在するだけで true になるので、値の有無だけをチェック
            if (value === true) {
                element.setAttribute(name, ''); // 値が true の場合は属性名だけ追加
            } else if (value !== false && value !== null && value !== undefined) {
                element.setAttribute(name, value);
            }
        });
        if (text) element.textContent = text;
        return element;
    }

    const recoveryOptionRadioGroup = document.getElementById("recoveryOptionRadioGroup");

    const addRecoveryOptionRadio = (label, value, checked) => {
        const radio = createElement("input", {
            type: "radio",
            name: "recoveryOption",
            value,
            checked
        });
        const labelElement = createElement("label", {}, label);

        const row = createElement("tr");
        const radioCell = createElement("td");
        const labelCell = createElement("td");
        radioCell.appendChild(radio);
        labelCell.appendChild(labelElement);
        row.appendChild(radioCell);
        row.appendChild(labelCell);
        recoveryOptionRadioGroup.appendChild(row);
    };

    chrome.storage.sync.get({ recoveryOption: "on" }, (obj) => {
        addRecoveryOptionRadio("回復ON", "on", obj.recoveryOption === "on");
        addRecoveryOptionRadio("回復OFF", "off", obj.recoveryOption === "off");
    });

    document.getElementById("saveButton").addEventListener("click", function () {
        const recoveryOption = document.querySelector(
            'input[name="recoveryOption"]:checked'
        ).value;
        const waitTime = document.getElementById("waitTime").value;
        const buttonSettings = [];

        const getButtonCount = (buttonType) => {
            const buttonCountElement = document.getElementById(`buttonCount${buttonType}`);
            return buttonCountElement ? parseInt(buttonCountElement.value, 10) : 0;
        };

        const processButtonInputs = (buttonType) => {
            const buttonCount = getButtonCount(buttonType);
            for (let i = 1; i <= buttonCount; i++) {
                const buttonTextElement = document.getElementById(`button${buttonType}${i}Text`);
                const buttonText =
                    buttonTextElement && buttonTextElement.value
                        ? buttonTextElement.value
                        : `リンク${buttonType}${i}`;
                const buttonUrlElement = document.getElementById(`button${buttonType}${i}Url`);
                const buttonUrl = buttonUrlElement && buttonUrlElement.value
                    ? buttonUrlElement.value
                    : "";
                buttonSettings.push({ type: buttonType, text: buttonText, url: buttonUrl });
            }
        };
        const buttonCountB = getButtonCount("B");
        const buttonCountL = getButtonCount("L");
        const buttonCountR = getButtonCount("R");

        processButtonInputs("B");
        processButtonInputs("L");
        processButtonInputs("R");


        chrome.storage.sync.set(
            {
                buttonCountB: buttonCountB,
                buttonCountL: buttonCountL,
                buttonCountR: buttonCountR,
                waitTime: waitTime,
                buttonSettings: buttonSettings,
                recoveryOption: recoveryOption
            },
            function () {
                console.log("Settings saved:", {
                    buttonCountB,
                    buttonCountL,
                    buttonCountR,
                    waitTime,
                    buttonSettings,
                    recoveryOption,
                });
                displayStatusMessage("保存しました", true);
            }
        );
    });

    function displayStatusMessage(message, success) {
        const statusMessageElement = document.getElementById("statusMessage");
        statusMessageElement.textContent = message;
        statusMessageElement.style.color = success ? "green" : "red";
        setTimeout(() => {
            statusMessageElement.textContent = "";
        }, 3000);
    }

    function getDefaultButtonSettings() {
        return Array.from({ length: 10 }, (_, i) => ({
            type: "B",
            text: `リンクB${i + 1}`,
            url: "",
        })).concat(
            Array.from({ length: 10 }, (_, i) => ({
                type: "L",
                text: `リンクL${i + 1}`,
                url: "",
            }))
        ).concat(
            Array.from({ length: 10 }, (_, i) => ({
                type: "R",
                text: `リンクR${i + 1}`,
                url: "",
            }))
        );
    }


    chrome.storage.sync.get(
        {
            buttonCountB: 5,
            buttonCountL: 10,
            buttonCountR: 10,
            waitTime: 300,
            buttonSettings: getDefaultButtonSettings(),
            recoveryOption: "on",
        },
        function (data) {
            console.log("Loaded settings:", data);
            document.getElementById("buttonCountB").value = data.buttonCountB;
            document.getElementById("buttonCountL").value = data.buttonCountL;
            document.getElementById("buttonCountR").value = data.buttonCountR;
            document.getElementById("waitTime").value = data.waitTime;

            // Use the loaded data.buttonSettings to generate button text & URL fields
            ["B", "L", "R"].forEach((buttonType) => {
                generateButtonInputs(buttonType, data[`buttonCount${buttonType}`], data.buttonSettings);
            });
        }
    );


    function generateButtonInputs(buttonType, buttonCount, buttonSettings) {
        const buttonTextInputs = document.getElementById(`buttonTextInputs${buttonType}`);
        if (!buttonTextInputs) {
            console.error(`buttonTextInputs${buttonType} not found.`);
            return;
        }

        const filteredSettings = buttonSettings.filter(setting => setting.type === buttonType);

        buttonTextInputs.innerHTML = "";
        for (let i = 1; i <= buttonCount; i++) {
            const setting = filteredSettings[i - 1];

            const initialText = setting ? setting.text : `リンク${buttonType}${i}`;
            const initialUrl = setting ? setting.url : "";

            const inputText = createElement("input", {
                id: `button${buttonType}${i}Text`,
                type: "text",
            });
            inputText.value = initialText;

            const inputUrl = createElement("textarea", {
                id: `button${buttonType}${i}Url`,
                rows: "3",
                cols: "20",
            });
            inputUrl.textContent = initialUrl;

            const labelCell = createElement("td", {}, `ボタン${buttonType}${i}`);
            const row = createElement("tr");
            const textCell = createElement("td");
            const urlCell = createElement("td");
            textCell.appendChild(inputText);
            urlCell.appendChild(inputUrl);
            row.appendChild(labelCell);
            row.appendChild(textCell);
            row.appendChild(urlCell);
            buttonTextInputs.appendChild(row);
        }
    }

});
